#include <stdio.h>
#include <allegro.h>

#include "map.h"        //Map routines
#include "city.h"        //City routines
#include "sound.h"      //Sound processing routines
#include "prjxmain.h"   //Main hub of the game
#include "startup.h"    //Game startup routines
#include "central.h"    //Central game routines
#include "shutdown.h"   //Game shutdown routines
#include "keyboard.h"   //Keyboard handling routines
#include "graphics.h"   //Graphics processing routines
#include "menu.h"       //Menu routines

void TIMER_PlayerLoc()
{
   switch(GAME_STAT)
   {
      case CITY:
      case MAINMAP:
         rectfill(screen,1,190,319,199,COLOR_BLACK);
         textprintf(screen,font,1,190,COLOR_RED,"Player Location: %ix - %iy",(PL_player.x+8),(PL_player.y+5));

         textprintf(screen,font,275,1,COLOR_YELLOW,"  HP");
         rectfill(screen,275,10,319,20,COLOR_BLACK);
         textprintf(screen,font,275,10,COLOR_RED,"%i",PL_player.hp);

         textprintf(screen,font,275,31,COLOR_YELLOW,"  MP");
         rectfill(screen,275,40,319,50,COLOR_BLACK);
         textprintf(screen,font,275,40,COLOR_RED,"%i",PL_player.mp);

         textprintf(screen,font,275,61,COLOR_YELLOW," AMMO");
         rectfill(screen,275,70,319,80,COLOR_BLACK);
         textprintf(screen,font,275,70,COLOR_RED,"%i",PL_player.ammo);

         textprintf(screen,font,275,91,COLOR_YELLOW," EXP");
         rectfill(screen,275,100,319,110,COLOR_BLACK);
         textprintf(screen,font,275,100,COLOR_RED,"%i",PL_player.exp);

         textprintf(screen,font,275,121,COLOR_YELLOW,"LEVEL");
         rectfill(screen,275,130,319,140,COLOR_BLACK);
         textprintf(screen,font,275,130,COLOR_RED,"%i",PL_player.level);

         break;
   }

   if(PL_player.hp<=0 && (GAME_STAT==MAINMAP || GAME_STAT==CITY))
   {
      TIMER_CharMoveVar=-2;
   }

} END_OF_FUNCTION(TIMER_PlayerLoc);

void TIMER_MessageHandler()
{
   switch(GAME_STAT)
   {
      case MAINMAP:
      case CITY:
         switch(MH_MessageNeeded)
         {
            case 0:  //nothing going on
               rectfill(screen,1,170,319,179,COLOR_BLACK);
               rectfill(screen,1,180,319,189,COLOR_BLACK);
               break;
            case 1: //announcing entrance of city
               rectfill(screen,1,170,319,179,COLOR_BLACK);
               rectfill(screen,1,180,319,189,COLOR_BLACK);
               textprintf(screen,font,1,170,COLOR_YELLOW,"MSG: Entering %s",MH_Message);
               textprintf(screen,font,1,180,COLOR_YELLOW,"MSG:");
               MH_MessageNeeded=0;
               break;
         }
   }
}

void TIMER_CharMove()
{
   switch(GAME_STAT)
   {
      case CITY:
      case MAINMAP:
         TIMER_CharMoveVar=1;
         break;
   }
} END_OF_FUNCTION(TIMER_CharMove);

void RemoveTimers(void)
{
   remove_int(TIMER_CharMove);
   remove_int(TIMER_PlayerLoc);
   remove_int(TIMER_MessageHandler);
}

void InstallTimers(void)
{

   install_int_ex(TIMER_CharMove,BPM_TO_TIMER(80));
   install_int_ex(TIMER_PlayerLoc,BPS_TO_TIMER(10));
   install_int_ex(TIMER_MessageHandler,BPM_TO_TIMER(30));
   LOCK_FUNCTION(TIMER_CharMove);
   LOCK_FUNCTION(TIMER_PlayerLoc);
   LOCK_VARIABLE(PL_player);
   LOCK_VARIABLE(Map);
   LOCK_VARIABLE(GAME_STAT);
   LOCK_VARIABLE(SndVol);
   LOCK_VARIABLE(TIMER_CharMoveVar);
   LOCK_VARIABLE(MH_MessageNeeded);
   LOCK_VARIABLE(MH_Message);
   LOCK_VARIABLE(CityLoc);
}

int main()
{
   int GooBeR = 0;  // Dummy variable to keep the program looping

   SndVol = 51; // A Range from 0 to 255 in steps of 5 (or 3 for slidebar)
   MidiVol = 1; // 0 or 1 ... Off or On

   do_config();            // Do the dos sound configuration
   do_startup();           // Startup allegro graphics and sound
   do_logo();              // Present the logo screen
   show_mainmenu(1);       // Show the main menu
   do_mainmenu(KeyWay);    // Enter the Main Menu handling section


   InstallTimers();

   CITY_LoadCityLoc();

   do
   {
      switch(GAME_STAT)       // ** Find out where you are in the game
      {
         case MAINMENU:       // *!* In the main menu
            KBD_MainMenu();         // -*- Go to the keyboard handling routines for the main menu
            break;
         case SETUPMENU:      // *!* In the setup menu
            KBD_SetupMenu();        // -*- Go to the keyboard handling routines for the setup menu
            break;
         case MAINMAP:     // *!* In the main map
            switch(TIMER_CharMoveVar)
            {
               case -2:          // player died
                  fade_out(1);
                  show_mainmenu(1);       // Show the main menu
                  do_mainmenu(KeyWay);    // Enter the Main Menu handling section
                  break;
               case -1:
                  TIMER_CharMoveVar=0;
                  StartNewGame();
                  break;
               case 1:     // normal mainmap movement
                  MAP_MoveEnemies();  //move all enemies on the screen
                  MAP_CheckLocation(); //Check where you are to see if there's anything important there (enemy, etc.)
                  MAP_DisplayMap();
                  MAP_ShowPlayer(PL_player.direction);
                  TIMER_CharMoveVar=0;
                  break;
            }
            KBD_MainMap();          // -*- Go to the keyboard handling routines for the main map
            break;
         case CITY:     // *!* In the city map
            switch(TIMER_CharMoveVar)
            {
               case -2:          // player died
                  fade_out(1);
                  show_mainmenu(1);       // Show the main menu
                  do_mainmenu(KeyWay);    // Enter the Main Menu handling section
                  break;
               case -1:
                  TIMER_CharMoveVar=0;
                  StartNewGame();
                  break;
               case 1:     // normal mainmap movement
                  MAP_MoveEnemies();  //move all enemies on the screen
                  MAP_CheckLocation(); //Check where you are to see if there's anything important there (enemy, etc.)
                  MAP_DisplayMap();
                  MAP_ShowPlayer(PL_player.direction);
                  TIMER_CharMoveVar=0;
                  break;
            }
            KBD_City();          // -*- Go to the keyboard handling routines for the City Map
            break;
      }
   } while(GooBeR==0);
}



